@@ -27,6 +27,8 @@ from dexp.datasets.operations.deconv import dataset_deconv
 @click.option('--power', '-pw', type=float, default=1.0, help='Correction exponent, default for standard LR is 1, set to >1 for acceleration.', show_default=True)
 @click.option('--blindspot', '-bs', type=int, default=0, help='Blindspot based noise reduction. Provide size of kernel to use, must be an odd number: 3(recommended), 5, 7. 0 means no blindspot. ', show_default=True)
 @click.option('--backprojection', '-bp', type=str, default='tpsf', help='Back projection operator, can be: ‘tpsf’ (transposed PSF = classic) or ‘wb’ (Wiener-Butterworth =  accelerated) ', show_default=True)
+@click.option('--wb-order', '-wbo', type=int, default=5, help='Wiener-Butterworth order parameter, a higher `n` makes the filter transition slope closer to a hard cutoff, causing the ringing artifacts in the spatial domain.'
+                                                              'In contrast, a lower order `n` makes the transition slope gentler and sacrifice some spectral amplitude at spatial frequencies close to the cutoff.', show_default=True)
 @click.option('--objective', '-obj', type=str, default='nikon16x08na', help='Microscope objective to use for computing psf, can be: nikon16x08na or olympus20x10na', show_default=True)
 @click.option('--numape', '-na', type=float, default=None, help='Overrides NA value for objective.', show_default=True)
 @click.option('--dxy', '-dxy', type=float, default=0.485, help='Voxel size along x and y in microns', show_default=True)
@@ -54,6 +56,7 @@ def deconv(input_paths,
            power,
            blindspot,
            backprojection,
+           wb_order,
            objective,
            numape,
            dxy, dz,
@@ -93,6 +96,7 @@ def deconv(input_paths,
                        power=power,
                        blind_spot=blindspot,
                        back_projection=backprojection,
+                       wb_order=wb_order,
                        psf_objective=objective,
                        psf_na=numape,
                        psf_dxy=dxy,
