@@ -11,13 +11,13 @@ from dexp.cli.dexp_main import _default_workers_backend
 @click.option('--modes', '-m', type=str, default='max',
               help='Either one for all images, or one per image in the form of a sequence. Blending modes are: mean, add, satadd, max, alpha. In the add mode the values are clipped. For alpha-blending, we assume that RGB values are not ‘alpha-premultiplied’.',
               show_default=True)
-@click.option('--alphas', '-a', type=str, default=None,
+@click.option('--alphas', '-a', type=str, default='1.0',
               help='List of alpha values for each input image',
               show_default=True)
-@click.option('--scales', '-s', type=str, default=None,
+@click.option('--scales', '-s', type=str, default='1.0',
               help='List of scales ‘s’ for each input image, starting with the second one (first image has always a scale of 1). Scaled images must be of same dimension or smaller than the first images. ',
               show_default=True)
-@click.option('--translations', '-t', type=str, default=None, help='List of translations ‘x0,y0*x1,y1;...’ for each input image, starting with the second one (first image is always at 0,0). ',
+@click.option('--translations', '-t', type=str, default='0,0', help='List of translations ‘x0,y0|x1_y1|...’ for each input image, starting with the second one (first image is always at 0,0). If set to 0,0 no translation is performed for any image. ',
               show_default=True)
 @click.option('--borderwidth', '-bw', type=int, default=0, help='Border width added to insets. ', show_default=True)
 @click.option('--bordercolor', '-bc', type=str, default='1,1,1,1', help='Border color in RGBA format. For example: 1,1,1,1 is white.', show_default=True)
@@ -54,20 +54,22 @@ def blend(input_paths,
     else:
         modes = (modes,) * number_of_inputs
 
-    if alphas is None:
-        alphas = (1.0,) * number_of_inputs
-    else:
+    if ',' in alphas:
         alphas = tuple(float(alpha) for alpha in alphas.split(','))
-
-    if scales is None:
-        scales = (1,) * number_of_inputs
     else:
+        alphas = (float(alphas),) * number_of_inputs
+
+    if ',' in scales:
         scales = tuple(float(scale) for scale in scales.split(','))
-
-    if translations is None:
-        translations = ((0, 0),) * number_of_inputs
     else:
-        translations = tuple(tuple(float(v) for v in xy.split(',')) for xy in translations.split('*'))
+        scales = (float(scales),) * number_of_inputs
+
+    if '|' in translations:
+        translations = tuple(tuple(float(v) for v in xy.split(',')) for xy in translations.split('|'))
+    elif ',' in translations:
+        translations = (tuple(float(v) for v in translations.split(',')),) * number_of_inputs
+    else:
+        translations = ((0, 0),) * number_of_inputs
 
     bordercolor = tuple(float(v) for v in bordercolor.split(','))
 
