@@ -5,11 +5,11 @@ from dexp.processing.backends.cupy_backend import CupyBackend
 from dexp.processing.backends.numpy_backend import NumpyBackend
 
 
-def test_deconv_numpy():
+def test_deskew_numpy():
     with NumpyBackend():
         _demo_deskew(display=False)
 
-def test_deconv_cupy():
+def test_deskew_cupy():
     try:
         with CupyBackend():
             _demo_deskew(display=False)
