@@ -9,6 +9,7 @@ import numpy
 import zarr
 from arbol.arbol import aprint
 from zarr import open_group, convenience, CopyError, Blosc, Group
+import tensorstore as ts
 
 from dexp.datasets.base_dataset import BaseDataset
 from dexp.processing.backends.backend import Backend
@@ -159,10 +160,12 @@ class ZDataset(BaseDataset):
             return groups[0]
 
     @staticmethod
-    def _default_chunks(shape: Tuple[int], max_size: int = 2 ** 31) -> Tuple[int]:
+    def _default_chunks(shape: Tuple[int], dtype: Union[str, numpy.dtype], max_size: int = 2147483647) -> Tuple[int]:
+        if not isinstance(dtype, numpy.dtype):
+            dtype = numpy.dtype(dtype)
         width = shape[-1]
         height = shape[-2]
-        depth = min(max_size // (width * height), shape[-3])
+        depth = min(max_size // (dtype.itemsize * width * height), shape[-3])
         chunk = (1, depth, height, width)
         return chunk[-len(shape):]
 
@@ -264,9 +267,31 @@ class ZDataset(BaseDataset):
         cli_history.append(new_command)
         self._root_group.attrs[key] = cli_history
 
-    def get_array(self, channel: str, per_z_slice: bool = False, wrap_with_dask: bool = False):
+    def _load_tensorstore(self, array: zarr.Array):
+        metadata = {
+            'dtype': array.dtype.str,
+            'order': array.order,
+            'shape': array.shape,
+        }
+        ts_spec ={
+            'driver': 'zarr',
+            'kvstore': {
+                'driver': 'file',
+                'path': self._path,
+            },
+            'path': array.path,
+            'metadata': metadata,
+        }
+        return ts.open(ts_spec, create=False, open=True).result()
+
+    def get_array(self, channel: str, per_z_slice: bool = False, wrap_with_dask: bool = False, wrap_with_tensorstore: bool = False):
+        assert (wrap_with_dask != wrap_with_tensorstore) or wrap_with_dask == False
         array = self._arrays[channel]
-        return dask.array.from_array(array, chunks=array.chunks) if wrap_with_dask else array
+        if wrap_with_dask:
+            return dask.array.from_array(array, chunks=array.chunks)
+        elif wrap_with_tensorstore:
+            return self._load_tensorstore(array)
+        return array
 
     def get_stack(self, channel: str, time_point: int, per_z_slice: bool = False, wrap_with_dask: bool = False):
         stack_array = self.get_array(channel, per_z_slice=per_z_slice, wrap_with_dask=wrap_with_dask)[time_point]
@@ -308,11 +333,12 @@ class ZDataset(BaseDataset):
     def add_channel(self,
                     name: str,
                     shape: Tuple[int, ...],
-                    dtype,
+                    dtype: numpy.dtype,
                     chunks: Sequence[int] = None,
                     enable_projections: bool = True,
                     codec: str = 'zstd',
-                    clevel: int = 3) -> Any:
+                    clevel: int = 3,
+                    value: Optional[Any] = None) -> Any:
         """Adds a channel to this dataset
 
         Parameters
@@ -335,12 +361,12 @@ class ZDataset(BaseDataset):
             raise ValueError("Channel already exist!")
 
         if chunks is None:
-            chunks = self._default_chunks(shape)
+            chunks = self._default_chunks(shape, dtype)
 
         aprint(f"chunks={chunks}")
 
         # Choosing the fill value to the largest value:
-        fill_value = self._get_largest_dtype_value(dtype)
+        fill_value = self._get_largest_dtype_value(dtype) if value is None else value
 
         aprint(f"Adding channel: '{name}' of shape: {shape}, chunks:{chunks}, dtype: {dtype}, fill_value: {fill_value}, codec: {codec}, clevel: {clevel} ")
         compressor = Blosc(cname=codec, clevel=clevel, shuffle=Blosc.BITSHUFFLE)
@@ -402,7 +428,7 @@ class ZDataset(BaseDataset):
         """
 
         if type(zdataset) is str:
-            zdataset = ZDataset(zdataset, 'a', store)
+            zdataset = ZDataset(zdataset, 'a', store, parent=self)
 
         root = zdataset._root_group
 
