@@ -121,7 +121,7 @@ def test_unified_memory():
 def test_paralell():
     try:
         num_devices = len(CupyBackend.available_devices())
-        if num_devices == 1:
+        if num_devices <= 1:
             return
 
         def f(id):
@@ -142,7 +142,7 @@ def test_paralell():
 def test_paralell_with_exclusive():
     try:
         num_devices = len(CupyBackend.available_devices())
-        if num_devices == 1:
+        if num_devices <= 1:
             return
 
         aprint(f"num_devices = {num_devices}")
@@ -181,6 +181,9 @@ def test_stress():
         size = 320
 
         num_devices = len(CupyBackend.available_devices())
+        if num_devices <= 0:
+            return
+
         aprint(f"num_devices = {num_devices}")
 
         def f(id, device):
