@@ -1,7 +1,8 @@
 from dexp.processing.backends.backend import Backend
+from dexp.utils import xpArray
 
 
-def gray2rgba(image,
+def gray2rgba(image: xpArray,
               alpha=None,
               rgba_value_max: float = 255):
     """Create a RGBA representation of a gray-level image.
