@@ -16,8 +16,8 @@ from dexp.processing.color.insert import insert_color_image
 def blend_color_image_sequences(input_paths: Sequence[str],
                                 output_path: str = None,
                                 modes: Union[str, Sequence[str]] = 'max',
-                                alphas: Sequence[float] = None,
-                                scales: Sequence[float] = None,
+                                alphas: Union[float, Sequence[float]] = None,
+                                scales: Union[float, Sequence[float]] = None,
                                 translations: Union[str, Sequence[Tuple[Union[int, float], ...]]] = None,
                                 background_color: Tuple[float, float, float, float] = (0, 0, 0, 0),
                                 border_width: int = 1,
